@@ -49,6 +49,7 @@
 #include <QDebug>
 
 #include <algorithm>
+#include <TabletModeWatcher>
 
 #ifdef Q_OS_LINUX
 #include <sys/timerfd.h>
@@ -60,8 +61,6 @@ namespace PowerDevil
 Core::Core(QObject* parent)
     : QObject(parent)
     , m_hasDualGpu(false)
-    , m_backend(nullptr)
-    , m_notificationsWatcher(nullptr)
     , m_criticalBatteryTimer(new QTimer(this))
     , m_activityConsumer(new KActivities::Consumer(this))
     , m_pendingWakeupEvent(true)
@@ -121,7 +120,11 @@ void Core::onBackendReady()
         qCDebug(POWERDEVIL) << "Generating a default configuration";
         bool toRam = m_backend->supportedSuspendMethods() & PowerDevil::BackendInterface::ToRam;
         bool toDisk = m_backend->supportedSuspendMethods() & PowerDevil::BackendInterface::ToDisk;
-        ProfileGenerator::generateProfiles(toRam, toDisk);
+
+        // These are generated profiles,
+        const bool mobile = Kirigami::TabletModeWatcher::self()->isTabletModeAvailable();
+
+        ProfileGenerator::generateProfiles(mobile, toRam, toDisk);
         m_profilesConfig->reparseConfiguration();
     }
 
@@ -294,7 +297,7 @@ void Core::loadProfile(bool force)
     QString activity = m_activityConsumer->currentActivity();
     qCDebug(POWERDEVIL) << "Currently using activity " << activity;
     KConfigGroup activitiesConfig(m_profilesConfig, "Activities");
-    qCDebug(POWERDEVIL) << activitiesConfig.groupList() << activitiesConfig.keyList();
+    qCDebug(POWERDEVIL) << "Activities with settings:" << activitiesConfig.groupList() << activitiesConfig.keyList();
 
     // Are we mirroring an activity?
     if (activitiesConfig.group(activity).readEntry("mode", "None") == QStringLiteral("ActLike") &&
@@ -307,7 +310,7 @@ void Core::loadProfile(bool force)
     }
 
     KConfigGroup activityConfig = activitiesConfig.group(activity);
-    qCDebug(POWERDEVIL) << activityConfig.groupList() << activityConfig.keyList();
+    qCDebug(POWERDEVIL) << "Settings for loaded activity:" << activity << activityConfig.groupList() << activityConfig.keyList();
 
     // See if this activity has priority
     if (activityConfig.readEntry("mode", "None") == QStringLiteral("SeparateSettings")) {
